@@ -19,6 +19,19 @@ describe JSON::JWT do
     'eyJ0eXAiOiJKV1QiLCJhbGciOiJub25lIn0.eyJpc3MiOiJqb2UiLCJleHAiOjEzMDA4MTkzODAsImh0dHA6Ly9leGFtcGxlLmNvbS9pc19yb290Ijp0cnVlfQ.'
   end
 
+  its(:version) do
+    JSON::JWT::VERSION.should_not be_blank
+  end
+
+  describe '#initialize' do
+    it "doesn't try to modify a frozen hash" do
+      claims = { iss: 'joe', exp: '1300819380' }.freeze
+      jwt = JSON::JWT.new(claims)
+      expect(jwt[:exp]).to eql 1300819380
+      expect(claims[:exp]).to eql '1300819380'
+    end
+  end
+
   context 'when not signed nor encrypted' do
     it do
       jwt.to_s.should == no_signed
@@ -500,6 +513,14 @@ describe JSON::JWT do
         end
       end
     end
+
+    context 'when JWS & JWE can be mixed-up (CVE-2023-51774)' do
+      it do
+        expect do
+          JSON::JWT.decode 'header.encrypted_key.iv.cipher_text.authentication_tag', 'secret', nil, nil, true
+        end.to raise_error JSON::JWT::InvalidFormat
+      end
+    end
   end
 
   describe '.pretty_generate' do
